@@ -1,6 +1,6 @@
 #! /bin/false
 
-# Copyright (C) 2016-2017 Guido Flohr <guido.flohr@cantanea.com>,
+# Copyright (C) 2016-2018 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
 # This program is free software; you can redistribute it and/or modify it
@@ -19,7 +19,7 @@
 # USA.
 
 package Locale::XGettext::TT2;
-$Locale::XGettext::TT2::VERSION = '0.2';
+$Locale::XGettext::TT2::VERSION = '0.3';
 use strict;
 
 use Locale::TextDomain qw(Template-Plugin-Gettext);
@@ -35,7 +35,7 @@ This is free software: you are free to change and redistribute it.
 There is NO WARRANTY, to the extent permitted by law.
 Written by Guido Flohr (http://www.guido-flohr.net/).
 ',
-    program => $0, years => '2016-2017', 
+    program => $0, years => '2016-2018', 
     version => $Locale::XGettext::VERSION);
 }
 
@@ -54,6 +54,17 @@ sub canKeywords {
     shift;
 }
 
+sub languageSpecificOptions {
+    return [
+        [
+            'plugin|plug-in=s',
+            'plug_in',
+            '    --plug-in=PLUG-IN, --plugin=PLUG-IN',
+            __"the plug-in name (defaults to 'Gettext')",
+        ]
+    ];
+}
+
 sub defaultKeywords {
     return [
                'gettext:1',
@@ -109,7 +120,7 @@ sub readFile {
 }
 
 package Locale::XGettext::TT2::Parser;
-$Locale::XGettext::TT2::Parser::VERSION = '0.2';
+$Locale::XGettext::TT2::Parser::VERSION = '0.3';
 use strict;
 
 use Locale::TextDomain qw(Template-Plugin-Gettext);
@@ -122,7 +133,9 @@ sub split_text {
     my $chunks = $self->SUPER::split_text($text) or return;
 
     my $keywords = $self->{__xgettext}->keywords;
-    
+    my $plug_in = $self->{__xgettext}->option('plug_in');
+    $plug_in = 'Gettext' if !defined $plug_in;
+
     my $ident;
     while (my $chunk = shift @$chunks) {
         if (!ref $chunk) {
@@ -135,12 +148,12 @@ sub split_text {
         next if !ref $tokens;
 
         if ('USE' eq $tokens->[0] && 'IDENT' eq $tokens->[2]) {
-            if ('Gettext' eq $tokens->[3]
+            if ($plug_in eq $tokens->[3]
                 && (4 == @$tokens
                     || '(' eq $tokens->[4])) {
-                $ident = 'Gettext';
+                $ident = $plug_in;
             } elsif ('ASSIGN' eq $tokens->[4] && 'IDENT' eq $tokens->[6]
-                     && 'Gettext' eq $tokens->[7]) {
+                     && $plug_in eq $tokens->[7]) {
                 $ident = $tokens->[3];
             }
             next;
