@@ -1,6 +1,6 @@
 #! /bin/false
 
-# Copyright (C) 2016-2017 Guido Flohr <guido.flohr@cantanea.com>,
+# Copyright (C) 2016-2018 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
 # This program is free software; you can redistribute it and/or modify it
@@ -21,11 +21,9 @@
 # ABSTRACT: Gettext Support For the Template Toolkit Version 2
 
 package Template::Plugin::Gettext;
-
+$Template::Plugin::Gettext::VERSION = '0.3';
 use strict;
 
-our $VERSION = 0.2;
-
 use Locale::TextDomain 1.20 qw(com.cantanea.Template-Plugin-Gettext);
 use Locale::Messages;
 use Locale::Util qw(web_set_locale);
@@ -62,7 +60,6 @@ sub new {
 
     my $template = $ctx->stash->get('component')->name;
     if ('input text' eq $template || 'input file handle' eq $template) {
-            $DB::single = 1;
         my $maybe_template = $ctx->stash->get('gettext_filename');
         $template = $maybe_template
             if defined $maybe_template && length $maybe_template;
